dofile("Prison Escape Ep3.rte/Scripts/RobotAnimation.lua");
dofile("Prison Escape Ep3.rte/Scripts/Mission.lua");
dofile("Prison Escape Ep3.rte/Scripts/Epilogue.lua");

-------------------
-- Miscellaneous --
-------------------

--Makes text appear and puts a marker over the person talking.
function PrisonEscapeMission3:Speak(speaker, text, length)
	--Set the text.
    self.curText = string.upper(speaker.PresetName) .. ": " .. text;
    
    if length == -1 then
        self.curText = self.curText .. "\r\n(Press SPACE to advance text)";
    end
	
	--Add the marker.
    if MovableMan:IsParticle(self.speechMarker) then
        self.speechMarker.ToDelete = true;
    end
    
	self.speechMarker = CreateAEmitter("Prison Escape Ep3.rte/Speech Marks");
	MovableMan:AddParticle(self.speechMarker);
    
    --Set the MO as the speaker's head, if it has one.
	if speaker.ClassName == "AHuman" then
        self.speaker = ToAHuman(speaker).Head;
    else
        self.speaker = speaker;
    end
	self.speakLength = length;
    self.speakTimer:Reset();
    self.speaking = true;
end

--Makes the screen shake.
function PrisonEscapeMission3:ShakeScreen(magnitude, length)
    self.cameraSpeed = 1;
    self.maxScreenShake = magnitude;
    self.shakeLength = length;
    self.shakeTimer:Reset();
end

--Copies a table.
function CopyTable(tableA)
    local tableB = {};
    for k, v in pairs(tableA) do
        tableB[k] = v;
    end
    return tableB;
end

----------
-- Math --
----------

--Gets the angle of c using the Law of Cosines.
function CosLawAngle(sideA, sideB, sideC)
    return math.acos((sideA ^ 2 + sideB ^ 2 - sideC ^ 2) / (2 * sideA * sideB));
end

--Interpolates an angle, wrapping nicely over the 0-2pi border.
function InterpolateAngle(a, b, speed)
    --Make sure the numbers are between 0 and 2pi.
    a = math.mod(a, 2 * math.pi);
    b = math.mod(b, 2 * math.pi);
    
    --If the shortest route doesn't wrap past 0, just interpolate normally.
    if math.abs(a - b) <= math.pi then
        return a + (b - a) * speed;
    end
    
    --Otherwise, offset the interpolation so it starts at 0.
    local delta;
    if a > b then
        delta = math.pi * 2 - a;
        a = 0;
        b = b + delta;
    else
        delta = math.pi * 2 - b;
        b = 0;
        a = a + delta;
    end
    
    --Apply the interpolation, then subtract the delta.
    return math.mod(a + (b - a) * speed - delta, math.pi * 2);
end

--Gibs all parts of the given actor. Also accepts part of an actor as an argument.
function GibActor(actor)
	for i = 1, MovableMan:GetMOIDCount() - 1, 1 do
		local mo = MovableMan:GetMOFromID(i);
		if mo.RootID == actor.RootID then
			ToMOSRotating(mo):GibThis();
		end
	end
end

-------------
-- Mission --
-------------

--Moves to the next scripted event.
function PrisonEscapeMission3:NextEvent(resetTimer)
    self.curEvent = self.curEvent + 1;
    if resetTimer then
        self.eventTimer:Reset();
    end
end

function PrisonEscapeMission3:StartActivity()
    SceneMan.Scene:GetArea("PE3");
    
    --Timer for mission events.
    self.eventTimer = Timer();
    
    --The current event.
    self.curEvent = 0;
    
    --The timer for speaking.
    self.speakTimer = Timer();
    
    --How long to speak for.
    self.speakLength = 0;
    
    --The current text to display.
    self.curText = "";
    
    --Whether somebody is speaking.
    self.speaking = false;

    if SceneMan.Scene.PresetName == "Ronin Headquarters" then
        self:StartMission();
    else
        self:StartEpilogue();
    end
end

function PrisonEscapeMission3:UpdateActivity()
    self:SetTeamFunds(0, Activity.TEAM_1);
    
    if self.speaking then
        --Show the text.
        self:ResetMessageTimer(Activity.PLAYER_1);
        FrameMan:ClearScreenText(Activity.PLAYER_1);
        
        local showText = true;
        
        --Keep the marker alive.
        self.speechMarker.ToDelete = false;
    
        --If this is in press-to-advance mode...
        if self.speakLength == -1 then
            if UInputMan:KeyPressed(75) then
                showText = false;
                self.speaking = false;
                if MovableMan:IsParticle(self.speechMarker) then
                    self.speechMarker.ToDelete = true;
                end
            end
            
        --If this is in timed mode...
        else
            --Once the timer is up, remove the marker and stop showing text.
            if self.speakTimer:IsPastSimMS(self.speakLength) then
                showText = false;
                self.speaking = false;
                if MovableMan:IsParticle(self.speechMarker) then
                    self.speechMarker.ToDelete = true;
                end
            end
        end
        
        --Move the speech mark into place, if the speaker still exists.
        if self.speaker.ID ~= 255 then
            self.speechMarker.Pos = self.speaker.Pos;
            self.speechMarker.HFlipped = self.speaker.HFlipped;
            self.speechMarker.RotAngle = self.speaker.RotAngle;
        else
            FrameMan:ClearScreenText(Activity.PLAYER_1);
            self.speechMarker.ToDelete = true;
            self.speaking = false;
            showText = false;
        end
        
        if showText then
            FrameMan:SetScreenText(self.curText, Activity.PLAYER_1, 0, 100, false);
        end
    end
    
    --Update the activity.
    if SceneMan.Scene.PresetName == "Ronin Headquarters" then
        self:UpdateMission();
    else
        self:UpdateEpilogue();
    end
end

function PrisonEscapeMission3:EndActivity()
    if SceneMan.Scene.PresetName == "Ronin Headquarters" then
        self:EndMission();
    else
        self:EndEpilogue();
    end
end