function PrisonEscapeMission3:StartMission()
    AudioMan:StopMusic();
    
    --How much to shake the screen (in pixels, relative to the center of the screen).
    self.screenShake = 0;
    
    --The maximum screen shake for this shake.
    self.maxScreenShake = 0;
    
    --Timer for decaying screen shake.
    self.shakeTimer = Timer();
    
    --How long the shake will last.
    self.shakeLength = 0;
    
    --Set up the boss.
    self:InitBoss();
    
    --Whether the boss has been defated.
    self.bossDefeated = false;
    
    --Whether the boss has started.
    self.bossStarted = false;

	--Create an invisible brain.
	self.brain = CreateActor("Base.rte/Brain Case");
	self.brain.Team = Activity.TEAM_1;
	self.brain.Pos = Vector(SceneMan.SceneWidth, 0);
	self.brain.Scale = 0;
	self.brain.GetsHitByMOs = false;
	self.brain.HitsMOs = false;
	MovableMan:AddActor(self.brain);
	self:SetPlayerBrain(self.brain, Activity.PLAYER_1);
    
    --The spawn point.
    self.spawnPos = Vector(1128, 500);
    
    --Spawn the player.
    playerActor = CreateAHuman("Prison Escape Ep3.rte/Dafred");
    playerActor.Team = Activity.TEAM_1;
    playerActor:SetControllerMode(Controller.CIM_NETWORK, -1);
    playerActor:AddInventoryItem(CreateHDFirearm("Prison Escape Ep3.rte/Amazon Pistol"));
    
    --Spawn Fiona.
    self.partner = CreateAHuman("Prison Escape Ep3.rte/Fiona");
    self.partner.Team = Activity.TEAM_1;
    self.partner:SetControllerMode(Controller.CIM_NETWORK, -1);
    self.partner:AddInventoryItem(CreateHDFirearm("Prison Escape Ep3.rte/Amazon Pistol"));
    
    --Put them in a rocket.
    self.rocket = CreateACRocket("Prison Escape Ep3.rte/Rocket MK2");
    self.rocket.Team = Activity.TEAM_1;
    self.rocket.Pos = Vector(330, 0);
    self.rocket:AddInventoryItem(playerActor);
    self.rocket:AddInventoryItem(self.partner);
    MovableMan:AddActor(self.rocket);
    self:SwitchToActor(self.rocket, Activity.PLAYER_1, Activity.TEAM_1);
    
    --What the camera should be focusing on.
    self.target = self.rocket;
    
    --What AIMode the target should be in.
    self.targetMode = Controller.CIM_NETWORK;
    
    --How many times the player has respawned.
    respawns = 0;
    
    --The maximum number of respawns.
	if self.Difficulty <= GameActivity.CAKEDIFFICULTY then
	    self.maxRespawns = 6;
	elseif self.Difficulty <= GameActivity.EASYDIFFICULTY then
	    self.maxRespawns = 4;
	elseif self.Difficulty <= GameActivity.MEDIUMDIFFICULTY then
	    self.maxRespawns = 3;
	elseif self.Difficulty <= GameActivity.HARDDIFFICULTY then
	    self.maxRespawns = 3;
	elseif self.Difficulty <= GameActivity.NUTSDIFFICULTY then
	    self.maxRespawns = 2;
	elseif self.Difficulty <= GameActivity.MAXDIFFICULTY then
	    self.maxRespawns = 0;
	end
    
    --A general timer for the mission.
    self.missionTimer = Timer();
    
    --Whether the player got the RPC.
    self.hasRPC = false;
    
    --Whether the player got the digger.
    self.hasDigger = false;
    
    --Set the lerp speeds for the boss' parts.
    self:ResetLerpSpeeds();
    
    --Whether the camera is locked in place yet.
    self.cameraLocked = false;
    
    --How quickly to move the camera.
    self.cameraSpeed = 0.1;
    
    --Where the camera should lock.
    self.cameraPos = Vector(1128, 384);
    
    --Hide the underground.
    SceneMan:MakeAllUnseen(Vector(12, 12), Activity.TEAM_1);
    for i = 0, SceneMan.SceneWidth, 12 do
        SceneMan:CastSeeRay(Activity.TEAM_1, Vector(i, 0), Vector(0, SceneMan.SceneHeight), Vector(), 50, 0);
    end
    
    --Make the bunker top visible.
    SceneMan:CastSeeRay(Activity.TEAM_1, Vector(792, 540), Vector(672, 0), Vector(), 999999, 6);
end

function PrisonEscapeMission3:UpdateMission()
    self.brain.Team = -1;
    
    --Update the shake amount.
    if self.shakeTimer.ElapsedRealTimeMS < self.shakeLength then
        self.screenShake = self.maxScreenShake * (1 - (self.shakeTimer.ElapsedRealTimeMS / self.shakeLength));
    else
        self.screenShake = 0;
    end
    
    if self.cameraLocked then
        --Keep the camera centered on the boss and shake it if needed.
        SceneMan:SetScrollTarget(self.cameraPos + Vector(math.random() * self.screenShake * 2 - self.screenShake, math.random() * self.screenShake * 2 - self.screenShake), self.cameraSpeed, false, Activity.PLAYER_1);
    end
        
    --Remove any stray items.
    for item in MovableMan.Items do
        if (item.PresetName ~= "RPC M17" or self.hasRPC) and (item.PresetName ~= "Light Digger" or self.hasDigger) and item.PresetName ~= "Richard Borno" then
            item.ToDelete = true;
        end
    end
    
    --Keep the life bar alive and color it correctly.
    if #self.lifebarPieces > 0 then
        local pieceCount = #self.lifebarPieces;
        for i = 0, pieceCount do
            self.lifebarPieces[i].ToDelete = false;
            self.lifebarPieces[i].Age = 0;
            if i > 0 and i < pieceCount then
                if math.ceil((pE3BossHealth / self.maxBossHealth) * (pieceCount - 2)) >= i - 1 then
                    self.lifebarPieces[i].Frame = 1;
                else
                    self.lifebarPieces[i].Frame = 2;
                end
            end
        end
        
        self.lifebarName.ToDelete = false;
        self.lifebarName.Age = 0;
    end
    
    if not self:ActivityOver() then
        --Scripted events start here.
        
		--Clear objective markers so we can add them.
		self:ClearObjectivePoints();
        
        _G["PE3MissionEvent" .. self.curEvent](self);
        
        if MovableMan:IsActor(self.partner) or self.curEvent <= 1 or self.curEvent >= 27 then
            --Don't let the stupid rocket knock itself over.
            if self.curEvent >= 1 then
                if MovableMan:IsActor(self.rocket) then
                    if self.curEvent < 7 then
                        self.rocket.Pos = self.landingPos;
                        self.rocket.RotAngle = self.landingAngle;
                        self.rocket:SetControllerMode(Controller.CIM_NETWORK, -1);
                        
                        --Make it relentlessly jitter so it doesn't auto-scuttle.
                        self.rocket.Vel = Vector(math.random() * 1 - 0.5, math.random() * 1 - 0.5);
                        self.rocket.AngularVel = math.random() * 1 - 0.5;
                    else
                        self.rocket.ToDelete = true;
                    end
                end
            end
            
            if self.curEvent >= 1 and self.curEvent <= 3 then
                if self.targetMode == Controller.CIM_NETWORK then
                    if playerActor.Pos.X < self.rocket.Pos.X + 100 then
                        --Walk out of the way.
                        playerActor:GetController():SetState(Controller.MOVE_RIGHT, true);
                        playerActor:SetControllerMode(Controller.CIM_NETWORK, -1);
                        
                        --Unstick him when he gets stuck.
                        if playerActor.Vel.Magnitude < 0.5 and playerActor.Vel.Magnitude > -0.5 then
                            playerActor.Pos.Y = playerActor.Pos.Y - 1;
                        end
                    else
                        --Turn to face Fiona.
                        playerActor.HFlipped = true;
                        
                        --Pistols do weird things to turning, so look down a bit.
                        playerActor:SetAimAngle(-0.1);
                    end
                end
            end
            
            if self.curEvent >= 1 and self.curEvent <= 27 then
                --Stop at the boss' center position.
                if playerActor.Pos.X > self.bossPos.X then
                    playerActor:SetControllerMode(Controller.CIM_NETWORK,-1);
                    self.targetMode = Controller.CIM_NETWORK;
                    
                    if playerActor.Vel.X > 0 then
                        playerActor.Vel.X = 0;
                    end
                    
                    playerActor.Pos.X = self.bossPos.X;
                    
                    --Turn around.
                    playerActor:GetController():SetState(Controller.MOVE_RIGHT, false);
                    playerActor:GetController():SetState(Controller.MOVE_LEFT, true);
                    
                    self.atBoss = true;
                end
            end
            
            if self.curEvent >= 6 and self.curEvent <= 27 then
                --Keep Fiona unstuck from the ground.
                if self.partner.Vel.Magnitude < 0.25 and self.partner.Vel.Magnitude > -0.5 then
                    self.partner.Pos.Y = self.partner.Pos.Y - 0.5;
                end
                
                --Don't go beyond the point.
                if self.partner.Pos.X > 960 then
                    self.partner.Vel.X = 0;
                    self.partner.Pos.X = 960;
                end
            end
            
            self:YSortObjectivePoints();
        else
            --Game over! Fiona is dead.
            self.WinnerTeam = Activity.TEAM_2;
            ActivityMan:EndActivity();
        end
        
        --Scripted events end here.
    
        --Stay controlling the target.
        if MovableMan:IsActor(self.target) then
            --Stay controlling the target.
            if self:GetControlledActor(Activity.TEAM_1) == nil then
                self:SwitchToActor(self.target, Activity.PLAYER_1, Activity.TEAM_1);
            else
                --If the target isn't already controlled, switch to it.
                local other = self:GetControlledActor(Activity.PLAYER_1);
                if self.target.ID ~= other.ID then
                    self:SwitchToActor(self.target,Activity.PLAYER_1, Activity.TEAM_1);
                    
                    --Set the target's controller mode.
                    if self.targetMode == Controller.CIM_NETWORK then
                        self.target:SetControllerMode(Controller.CIM_NETWORK, -1);
                    else
                        self.target:SetControllerMode(Controller.CIM_PLAYER, Activity.PLAYER_1);
                    end
                    
                    --Set the last actor back to the right mode.
                    other:SetControllerMode(Controller.CIM_NETWORK, -1);
                end
            end
        end

        --Respawn the player if they died.
        local playerAlive = true;

        if MovableMan:IsActor(playerActor) == false then
            playerAlive = false;
        elseif playerActor.Health <= 0 then
            playerAlive = false;
        else
            --Don't let the player drop his guns.
            local cont = playerActor:GetController();
            cont:SetState(Controller.WEAPON_DROP, false);
        
            --Keep the player in the right mode.
            if playerActor:IsPlayerControlled() == false then
                --Set the target's controller mode.
                if self.targetMode == Controller.CIM_NETWORK then
                    playerActor:SetControllerMode(Controller.CIM_NETWORK,-1);
                else
                    playerActor:SetControllerMode(Controller.CIM_PLAYER,Activity.PLAYER_1);
                end
            end
            
            --Keep the player inside the level.
            if self.cameraLocked then
                if playerActor.Pos.Y < self.cameraPos.Y - 240 then
                    playerActor.Pos.Y = self.cameraPos.Y - 240;
                    playerActor.Vel.Y = 0;
                end
            else
                if playerActor.Pos.X < 0 then
                    playerActor.Pos.X = 0;
                    playerActor.Vel.X = 0;
                end
                
                if playerActor.Pos.X > SceneMan.SceneWidth then
                    playerActor.Pos.X = SceneMan.SceneWidth;
                    playerActor.Vel.X = 0;
                end
                
                if playerActor.Pos.Y < 0 then
                    playerActor.Pos.Y = 0;
                    playerActor.Vel.Y = 0;
                end
            end
            
            --Check if he picked up the RPC.
            if playerActor:HasObject("RPC M17") then
                self.hasRPC = true;
            end
            
            --Check if he picked up the Digger.
            if playerActor:HasObject("Light Digger") then
                self.hasDigger = true;
            end
        end
    
        --Respwan the player.
        if playerAlive == false and self.curEvent >= 1 then
            if respawns < self.maxRespawns then
                respawns = respawns + 1;
                
                self:ResetMessageTimer(Activity.PLAYER_1);
                FrameMan:ClearScreenText(Activity.PLAYER_1);
                if self.maxRespawns - respawns > 1 then
                    FrameMan:SetScreenText((self.maxRespawns - respawns) .. " LIVES LEFT!", Activity.PLAYER_1, 500, 5000, false);
                elseif self.maxRespawns - respawns == 1 then
                    FrameMan:SetScreenText("1 LIFE LEFT!", Activity.PLAYER_1, 500, 5000, false);
                else
                    FrameMan:SetScreenText("NO LIVES LEFT!", Activity.PLAYER_1, 500, 5000, false);
                end

                playerActor = CreateAHuman("Prison Escape Ep3.rte/Dafred");
                if self.hasRPC then
                    playerActor:AddInventoryItem(CreateHDFirearm("Prison Escape Ep3.rte/RPC M17"));
                    playerActor:AddInventoryItem(CreateHDFirearm("Prison Escape Ep3.rte/Light Digger"));
                else
                    playerActor:AddInventoryItem(CreateHDFirearm("Prison Escape Ep3.rte/Amazon Pistol"));
                end
                
                --Set the target to the player.
                self.target = playerActor;
                
                --Put him at the spawn point.
                playerActor.Pos = self.spawnPos;
                
                MovableMan:AddActor(playerActor);
                self:SwitchToActor(playerActor,Activity.PLAYER_1,Activity.TEAM_1);
            else
                --Game over!
                self:StartBossAnimation(self.animMode.WIN);
                self.WinnerTeam = Activity.TEAM_2;
                ActivityMan:EndActivity();
            end
        end
    end
    
    --Animate the boss. This function is defined in BossAnimation.lua (along with its start and stop functions), because it's huge.
    self:AnimateBoss();
    
    --Move the pieces now that the animation is set.
    if not self.bossDisabled then
        self:UpdateBoss();
    end
end

function PrisonEscapeMission3:EndMission()
    AudioMan:ClearMusicQueue();
    AudioMan:PlayMusic("Base.rte/Music/dBSoundworks/udiedfinal.ogg", 0, -1);
end

--------------------------------
-- EVENT FUNCTIONS START HERE --
--------------------------------

function PE3MissionEvent0(self)
    --Keep the rocket AI-controlled.
    self.rocket:SetControllerMode(Controller.CIM_AI, -1);
    
    if not self.eventTimer:IsPastSimMS(1500) then
        self:ResetMessageTimer(Activity.PLAYER_1);
        FrameMan:ClearScreenText(Activity.PLAYER_1);
        FrameMan:SetScreenText("Press SPACE to skip intro.", Activity.PLAYER_1, 250, 1500, true);
    end
    
    --Skip the intro.
    if UInputMan:KeyHeld(75) then
        --Spawn the player again.
        playerActor = CreateAHuman("Prison Escape Ep3.rte/Dafred");
        playerActor.Team = Activity.TEAM_1;
        playerActor:AddInventoryItem(CreateHDFirearm("Prison Escape Ep3.rte/Amazon Pistol"));
        playerActor.Pos = Vector(self.bossPos.X, 500);
        playerActor.HFlipped = true;
        MovableMan:AddActor(playerActor);
        self.target = playerActor;
        self.targetMode = Controller.CIM_NETWORK;
        
        --Spawn Fiona again.
        self.partner = CreateAHuman("Prison Escape Ep3.rte/Fiona");
        self.partner.Team = Activity.TEAM_1;
        self.partner:SetControllerMode(Controller.CIM_NETWORK, -1);
        self.partner:AddInventoryItem(CreateHDFirearm("Prison Escape Ep3.rte/Amazon Pistol"));
        self.partner.Pos = Vector(960, 500);
        MovableMan:AddActor(self.partner);
        
        self.skippedIntro = true;
        
        self:ResetMessageTimer(Activity.PLAYER_1);
        FrameMan:ClearScreenText(Activity.PLAYER_1);
        
        --Lock the camera.
        self.cameraLocked = true;
        self.cameraSpeed = 1;
        self.atBoss = true;
        
        self.curEvent = 25;
        self.eventTimer:Reset();
    else
        if not self.rocket:HasObject("Dafred") then
            --Shut the door so Fiona doesn't immediately come out.
            self.rocket:CloseHatch();
            
            --Play the music.
            AudioMan:ClearMusicQueue();
            AudioMan:PlayMusic("Prison Escape Ep3.rte/Sound/Music/ReHashed.ogg", -1, -1);
            
            --Where the rocket landed.
            self.landingPos = Vector(self.rocket.Pos.X, self.rocket.Pos.Y);
            self.landingAngle = self.rocket.RotAngle;
            
            --Switch to the player, but disable movement.
            self.target = playerActor;
            self.targetMode = Controller.CIM_NETWORK;
            
            --Timer for opening the ship's door.
            self.openTimer = Timer();
            
            self:NextEvent(true);
        end
    end
end

function PE3MissionEvent1(self)
    if playerActor.Pos.X >= self.rocket.Pos.X + 100 then
        if self.openTimer:IsPastSimMS(1000) then
            self.rocket:GetController():SetState(Controller.PRESS_FACEBUTTON, true);
            self.openTimer:Reset();
        end

        --Once Fiona is out, shut the door.
        if not self.rocket:HasObject("Fiona") then
            self.rocket:CloseHatch();
            
            --Make Dafred and Fiona not collide.
            for i=1,MovableMan:GetMOIDCount()-1 do
                local mo = MovableMan:GetMOFromID(i);
                if mo.RootID == self.partner.ID then
                    partsFound = true;
                    mo:SetWhichMOToNotHit(playerActor,-1);
                elseif mo.RootID == playerActor.ID then
                    mo:SetWhichMOToNotHit(self.partner,-1);
                end
            end
            
            self:NextEvent(true);
        end
    end
end

function PE3MissionEvent2(self)
    if self.eventTimer:IsPastSimMS(250) then
        self:Speak(self.partner, "Well, here we are... I hate to be cliche, but it seems too quiet.", -1);
        
        self:NextEvent(true);
    end
end

function PE3MissionEvent3(self)
    if not self.speaking then
        self:Speak(self.partner, "It sounded like they were in mid-battle when the communications cut out an hour ago.", -1);
        
        self:NextEvent(true);
    end
end

function PE3MissionEvent4(self)
    if not self.speaking then
        self:Speak(self.partner, "I guess... one of the sides must have won.", -1);
        
        self:NextEvent(true);
    end
end

function PE3MissionEvent5(self)
    if not self.speaking then
        self:Speak(self.partner, "Only one way to find out. You lead the way.", 3000);
        
        --Enable control.
        self.targetMode = Controller.CIM_PLAYER;
        
        self:NextEvent(true);
    end
end

function PE3MissionEvent6(self)
    self:AddObjectivePoint("Investigate the base!", Vector(self.bossPos.X, 480), Activity.TEAM_1,GameActivity.ARROWDOWN);

    if self.eventTimer:IsPastSimMS(1000) then
        --Make Fiona walk and jump over to the desired area.
        if self.partner.Pos.X > 600 and self.partner.Pos.X < 720 then
            self.partner:GetController():SetState(Controller.BODY_JUMP, true);
            self.partner.Vel.Y = -5;
        else
            if self.partner.Pos.X < playerActor.Pos.X - 80 and self.partner.Pos.X < 960 then
                self.partner:GetController():SetState(Controller.MOVE_RIGHT, true);
            end
        end
    end
    
    if self.atBoss then
        if self.partner.Pos.X > 950 then
            self:Speak(self.partner, "The entire upper section of the base has been leveled!", -1);
            
            --Move the camera into place.
            self.cameraLocked = true;
            
            self:NextEvent(true);
        end
    end
end

function PE3MissionEvent7(self)
    if not self.speaking then
        self:Speak(self.partner, "Somebody must really hate us... This was more than just soldiers.", -1);
        
        self:NextEvent(true);
    end
end

function PE3MissionEvent8(self)
    if not self.speaking then
        self.borno.PresetName = "???";
        self:Speak(self.borno, "You two are late! You missed the party!", -1);
        
        self:NextEvent(true);
    end
end

function PE3MissionEvent9(self)
    if not self.speaking then
        self:Speak(self.partner, "I know that voice! Borno! What the hell are you doing here?!", -1);
        
        self:NextEvent(true);
    end
end

function PE3MissionEvent10(self)
    if not self.speaking then
        self.borno.PresetName = "Richard Borno";
        self:Speak(self.borno, "That's not a very nice way to speak to your former boss.", -1);
        
        self:NextEvent(true);
    end
end

function PE3MissionEvent11(self)
    if not self.speaking then
        self:Speak(self.partner, "Shove it. I don't owe you anything. What do you have to do with this mess?", -1);
        
        self:NextEvent(true);
    end
end

function PE3MissionEvent12(self)
    if not self.speaking then
        self:Speak(self.borno, "Plenty. I sent the troops here to capture you, originally.", -1);
        
        self:NextEvent(true);
    end
end

function PE3MissionEvent13(self)
    if not self.speaking then
        self:Speak(self.borno, "Little did I know, you left for the prison just before the attack began.", -1);
        
        self:NextEvent(true);
    end
end

function PE3MissionEvent14(self)
    if not self.speaking then
        self:Speak(self.borno, "As it turns out, your stunt there left both you AND your \"leader\" with huge bounties on your heads.", -1);
        
        self:NextEvent(true);
    end
end

function PE3MissionEvent15(self)
    if not self.speaking then
        self:Speak(self.borno, "I made my way here as quickly as I could when I discovered that you were returning.", -1);
        
        self:NextEvent(true);
    end
end

function PE3MissionEvent16(self)
    if not self.speaking then
        self:Speak(self.partner, "You sick bastard! If you just wanted us, why did you kill everyone else?", -1);
        
        self:NextEvent(true);
    end
end

function PE3MissionEvent17(self)
    if not self.speaking then
        self:Speak(self.borno, "The boys found some fascinating technology of yours in the basement.", -1);
        
        self:NextEvent(true);
    end
end

function PE3MissionEvent18(self)
    if not self.speaking then
        self:Speak(self.borno, "I thought I'd take it for a test run before you got here. You can see the results for yourselves.", -1);
        
        self:NextEvent(true);
    end
end

function PE3MissionEvent19(self)
    if not self.speaking then
        self:Speak(self.borno, "Don't worry, though. Your so-called guards are cowering in the blast shelter underground.", -1);
        
        self:NextEvent(true);
    end
end

function PE3MissionEvent20(self)
    if not self.speaking then
        self:Speak(self.borno, "My troops have left, too. I even took the liberty of jamming air signals.", -1);
        
        self:NextEvent(true);
    end
end

function PE3MissionEvent21(self)
    if not self.speaking then
        self:Speak(self.borno, "The only bodies present are me, you two, and the sweet smell of revenge. Isn't that nice?", -1);
        
        self:NextEvent(true);
    end
end

function PE3MissionEvent22(self)
    if not self.speaking then
        self:Speak(self.partner, "Quit talking and show yourself!", -1);
        
        self:NextEvent(true);
    end
end

function PE3MissionEvent23(self)
    if not self.speaking then
        self:Speak(self.borno, "I don't think you want me to do that.", -1);
        
        self:NextEvent(true);
    end
end

function PE3MissionEvent24(self)
    if not self.speaking then
        self:Speak(self.partner, "NOW.", -1);
        
        self:NextEvent(true);
    end
end

function PE3MissionEvent25(self)
    if not self.speaking or (self.skippedIntro and self.eventTimer:IsPastSimMS(100)) then
        self:Speak(self.borno, "Fine, have it your way...", -1);
        
        self:NextEvent(true);
    end
end

function PE3MissionEvent26(self)
    if not self.speaking then
        self:Speak(self.borno, "But don't say I didn't warn you!", 4000);
        AudioMan:StopMusic();
        
        self:NextEvent(true);
    end
end

function PE3MissionEvent27(self)
    if self.eventTimer:IsPastSimMS(2000) then
        --Reveal the boss.
        self:StartBossAnimation(self.animMode.REVEAL);
        
        self:NextEvent(true);
    end
end

function PE3MissionEvent28(self)
    --Remove Fiona when she's off-screen.
    if MovableMan:IsActor(self.partner) then
        if self.partner.Pos.X > self.bossPos.X + 320 then
            self.partner.ToDelete = true;
        end
    end
    
    --Move onto the next event once boss is dead.
    if self.bossDefeated then
        self:NextEvent(true);
    end
end

function PE3MissionEvent29(self)
    if self.eventTimer:IsPastSimMS(3000) then
        self.borno.GetsHitByMOs = true;
        
        self:AddObjectivePoint("Retrieve Borno's brain case!", self.borno.Pos + Vector(0, -32), Activity.TEAM_1,GameActivity.ARROWDOWN);
        
        if playerActor:HasObject("Richard Borno") then
            self.targetMode = Controller.CIM_NETWORK;
            playerActor:SetControllerMode(Controller.CIM_NETWORK, -1);
            playerActor:SetAimAngle(0);
        
            --Borno has been picked up.
            self:Speak(self.borno, "Oh no, you don't! Put me down! Put me down right this second!", -1);
            
            self:NextEvent(true);
        end
    end
end

function PE3MissionEvent30(self)
    if not self.speaking then
        self:Speak(self.borno, "I'll have you killed for this! Well... I already tried that, but I will for real this time!", -1);
        
        --Add Fiona. Didn't end up visibly using this sprite. Oh well.
        self.partner = CreateAHuman("Prison Escape Ep3.rte/Bruised Fiona");
        self.partner.PresetName = "Fiona";
        self.partner.Team = Activity.TEAM_1;
        self.partner:SetControllerMode(Controller.CIM_NETWORK, -1);
        self.partner.HFlipped = true;
        self.partner.Pos = Vector(1700, 500);
        MovableMan:AddActor(self.partner);
        
        self:NextEvent(true);
    end
end

function PE3MissionEvent31(self)
    if not self.speaking then
        self:Speak(self.partner, "...D-Dafred...? Are you still alive...? I... I think I need some help...", -1);
        
        self:NextEvent(true);
    end
end

function PE3MissionEvent32(self)
    if not self.speaking then
        self:Speak(self.borno, "What?! Not her, too! This wasn't supposed to happen!", -1);
        
        self:NextEvent(true);
    end
end

function PE3MissionEvent33(self)
    if not self.speaking then
        self:Speak(self.borno, "She should be dead!", -1);
        
        self:NextEvent(true);
    end
end

function PE3MissionEvent34(self)
    if not self.speaking then
        self:Speak(self.borno, "YOU should be dead!", -1);
        
        self:NextEvent(true);
    end
end

function PE3MissionEvent35(self)
    if not self.speaking then
        self:Speak(self.borno, "What are you people made of, rubber?!", -1);
        
        self:NextEvent(true);
    end
end

function PE3MissionEvent36(self)
    if not self.speaking then
        self:Speak(self.borno, "I mean, seriously! I hit you both with enough force to break a -", -1);
        
        self:NextEvent(true);
    end
end

function PE3MissionEvent37(self)
    if not self.speaking then
        self:Speak(playerActor, "Borno.", -1);
        
        self:NextEvent(true);
    end
end

function PE3MissionEvent38(self)
    if not self.speaking then
        self:Speak(self.borno, "...!", -1);
        
        self:NextEvent(true);
    end
end

function PE3MissionEvent39(self)
    if not self.speaking then
        self:Speak(playerActor, "Shut up.", -1);
        
        self:NextEvent(true);
    end
end

function PE3MissionEvent40(self)
    --Go to the epilogue scene.
    if not self.speaking then
        SceneMan:LoadScene("Prison Escape Ep. 3 Epilogue", false);
        PrisonEscapeMission3:StartActivity();
    end
end